<?php
/*
* Plugin Name: VHT SMS
* Version: 1.0.2
* Description: VHT SMS dành riêng cho khách hàng sử dụng dịch vụ của VHT, giúp quý khách gửi tin nhắn vào số điện thoại của khách hàng khi sử dụng Contact Form 7, NinjaForms hoặc Woocommerce.
* Author: VHT
* Author URI: https://vht.com.vn/
* Plugin URI:
* Text Domain: vhtsms
* Domain Path: /languages
* License: GPLv3
* License URI: http://www.gnu.org/licenses/gpl-3.0
* WC requires at least: 3.0.0
* WC tested up to: 6.6.0

VHT SMS

Copyright (C) 2018 VHT

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
if (
    in_array( 'contact-form-7/wp-contact-form-7.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
    ||
    in_array( 'ninja-forms/ninja-forms.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
    ||
    in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
){
    if (!class_exists('VHT_SMS_Class')) {
        class VHT_SMS_Class
        {
            protected static $instance;
            public $_version = '1.0.2';

            public $_optionName = 'vhtsms_options';
            public $_optionGroup = 'vhtsms-options-group';
            public $_defaultOptions = array(
                'kichhoat'      =>  '',
                'check_version' =>  '',
                'mess_content'  =>  '',
                'cf7_id'        =>  '',
                'smstype'       =>  4,
                'is_unicode'    =>  1,
                'mess_content_list' => array(),

                'enable_woo'    =>  '',
                'admin_phone' =>  '',

                'account_creat_mess'    =>  '',
                'account_creat'    =>  '',

                'order_creat'    =>  '',
                'order_creat_mess' =>  '',

                'woo_status_complete' =>  '',
                'woo_status_complete_mess' =>  '',

                'woo_status_processing' =>  '',
                'woo_status_processing_mess' =>  '',

                'woo_status_cancelled' =>  '',
                'woo_status_cancelled_mess' =>  '',

                'order_creat_admin' =>  '',
                'order_creat_admin_mess'    =>  '',

                'sandbox'    =>  '0',
                'type_api' =>   'user_pass',

                'user_vht' =>   '',
                'pass_vht' =>   '',
                'brandname'     =>  '',

                'apikey'        =>  '',
                'secretkey'     =>  '',
                'brandname_api'     =>  '',
            );

            public static function init()
            {
                is_null(self::$instance) AND self::$instance = new self;
                return self::$instance;
            }

            public function __construct()
            {
                $this->define_constants();
                global $vhtsms_settings;
                $vhtsms_settings = $this->get_vhtsmsoptions();

                add_action('plugins_loaded', array($this, 'vhtsms_load_textdomain'));

                add_filter('plugin_action_links_' . DEVVN_VHTSMS_BASENAME, array($this, 'add_action_links'), 10, 2);

                add_action('admin_menu', array($this, 'admin_menu'));
                add_action('admin_init', array($this, 'vhtsms_register_mysettings'));

                add_action( 'wpcf7_mail_sent', array($this, 'process_contact_form_data') );
                if(!$vhtsms_settings['check_version']) {
                    add_action('ninja_forms_after_submission', array($this, 'process_ninjaform_data'));
                }else {
                    add_action('ninja_forms_post_process', array($this, 'process_ninjaform_data_oldversion'));
                }

                add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );

                if($vhtsms_settings['kichhoat'] && $vhtsms_settings['enable_woo']) {

                    add_action('woocommerce_checkout_process', array($this, 'devvn_validate_phone_field_process') );

                    add_action('woocommerce_created_customer', array($this, 'sms_woocommerce_created_customer'), 10, 2);

                    if (
                        ($vhtsms_settings['order_creat'] && $vhtsms_settings['order_creat_mess']) ||
                        ($vhtsms_settings['order_creat_admin'] && $vhtsms_settings['order_creat_admin_mess'])
                    ) {
                        add_action('woocommerce_new_order', array($this, 'sms_woocommerce_new_order'), 10);
                    }

                    if (
                        (
                            ($vhtsms_settings['woo_status_complete'] && $vhtsms_settings['woo_status_complete_mess']) ||
                            ($vhtsms_settings['woo_status_processing'] && $vhtsms_settings['woo_status_processing_mess']) ||
                            ($vhtsms_settings['woo_status_cancelled'] && $vhtsms_settings['woo_status_cancelled_mess'])
                        )
                    ) {
                        add_action('woocommerce_order_status_changed', array($this, 'sms_woocommerce_order_status_changed'), 10, 3);
                    }
                }

            }

            public function define_constants()
            {
                if (!defined('DEVVN_VHTSMS_VERSION_NUM'))
                    define('DEVVN_VHTSMS_VERSION_NUM', $this->_version);
                if (!defined('DEVVN_VHTSMS_URL'))
                    define('DEVVN_VHTSMS_URL', plugin_dir_url(__FILE__));
                if (!defined('DEVVN_VHTSMS_BASENAME'))
                    define('DEVVN_VHTSMS_BASENAME', plugin_basename(__FILE__));
                if (!defined('DEVVN_VHTSMS_PLUGIN_DIR'))
                    define('DEVVN_VHTSMS_PLUGIN_DIR', plugin_dir_path(__FILE__));
            }

            public function add_action_links($links, $file)
            {
                if (strpos($file, 'vht-sms.php') !== false) {
                    $settings_link = '<a href="' . admin_url('options-general.php?page=setting-vhtsms') . '" title="'. __('Cài đặt', 'vhtsms') .'">' . __('Cài đặt', 'vhtsms') . '</a>';
                    array_unshift($links, $settings_link);
                }
                return $links;
            }
            function vhtsms_load_textdomain()
            {
                load_textdomain('vhtsms', dirname(__FILE__) . '/languages/vhtsms-' . get_locale() . '.mo');
            }

            function get_vhtsmsoptions()
            {
                return wp_parse_args(get_option($this->_optionName), $this->_defaultOptions);
            }

            function admin_menu()
            {
                add_options_page(
                    __('VHT SMS', 'vhtsms'),
                    __('VHT SMS', 'vhtsms'),
                    'manage_options',
                    'setting-vhtsms',
                    array(
                        $this,
                        'devvn_settings_page'
                    )
                );
            }

            function vhtsms_register_mysettings()
            {
                register_setting($this->_optionGroup, $this->_optionName);
            }

            function devvn_settings_page()
            {
                global $vhtsms_settings;
                $ninjsSelect = array();
                if(function_exists('Ninja_Forms')) {
                    if( isset(Ninja_Forms()->menus) ){
                        $ninjaForms = Ninja_Forms()->form()->get_forms();
                        if ($ninjaForms && !empty($ninjaForms)) {
                            foreach ($ninjaForms as $form) {
                                if (is_object($form)) {
                                    $id = $form->get_id();
                                    $name = $form->get_setting('title');
                                    $ninjsSelect['ninja_'.$id] = $name;
                                }
                            }
                        }
                    }else {
                        $ninjaForms = Ninja_Forms()->forms()->get_all();
                        if ($ninjaForms && !empty($ninjaForms)) {
                            foreach ($ninjaForms as $formid) {
                                $id = $formid;
                                $data = Ninja_Forms()->form( $id )->get_all_settings();
                                $name = $data['form_title'];
                                $ninjsSelect['ninja_'.$id] = $name;
                            }
                        }
                    }
                }
                $args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
                $cf7Select = array();
                if( $data = get_posts($args)){
                    foreach($data as $key){
                        $cf7Select['cf7_'.$key->ID] = $key->post_title;
                    }
                }
                ?>
                <div class="wrap">
                    <h1>Cài đặt VHT SMS</h1>
                    <form method="post" action="options.php" novalidate="novalidate">
                        <?php settings_fields($this->_optionGroup); ?>
                        <table class="form-table">
                            <tbody>
                            <tr>
                                <th scope="row"><label for="kichhoat"><?php _e('Kích hoạt', 'vhtsms') ?></label>
                                </th>
                                <td>
                                    <input type="checkbox" name="<?php echo $this->_optionName ?>[kichhoat]" id="kichhoat" value="1" <?php checked('1',intval($vhtsms_settings['kichhoat']), true) ; ?>/>
                                </td>
                            </tr>
                            <tr>
                                <th scope="row"><label for="admin_phone"><?php _e('Số điện thoại của Admin', 'vhtsms') ?></label>
                                </th>
                                <td>
                                    <input type="text" name="<?php echo $this->_optionName ?>[admin_phone]" id="admin_phone" value="<?php echo esc_attr($vhtsms_settings['admin_phone']);?>"/><br>
                                    <small>KHÔNG bắt buộc. Có thể thêm nhiều số ADMIN. Ví dụ: 0912345678, 0812345678...</small>
                                </td>
                            </tr>
                            </tbody>
                        </table>
                        <?php
                        if (
                            in_array( 'contact-form-7/wp-contact-form-7.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
                            ||
                            in_array( 'ninja-forms/ninja-forms.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
                        ){
                        ?>
                        <h2><?php _e('Cài đặt tin nhắn cho Contact Form 7 và NinjaForms','vhtsms');?></h2>
                        <table class="form-table">
                            <tbody>
                            <tr>
                                <th scope="row"><label for="check_version"><?php _e('NinjaForm version cũ', 'vhtsms') ?></label></th>
                                <td>
                                    <input type="checkbox" name="<?php echo $this->_optionName ?>[check_version]" id="check_version" value="1" <?php checked('1',intval($vhtsms_settings['check_version']), true) ; ?>/> Check vào đây nếu bạn đang chạy NinjaForm version cũ
                                </td>
                            </tr>
                            <tr>
                                <th scope="row"><label for="mess_content"><?php _e('Nội dung tin nhắn', 'vhtsms') ?><br><small><?php _e('Nhập nội dung tin nhắn tương ứng với mỗi form','vhtsms');?></small></label>
                                </th>
                                <td class="dbh-metabox-wrap">
                                    <table class="widefat devvn_bh_tablesetting">
                                        <thead>
                                        <tr>
                                            <th><?php _e('Nội dung tin nhắn','vhtsms');?></th>
                                            <th><?php _e('Chọn Form tương ứng','vhtsms');?></th>
                                            <th><?php _e('ID Field SĐT','vhtsms');?><br><small><?php _e('Dành cho NinjaForm phiên bản cũ','vhtsms');?></small></th>
                                            <th></th>
                                        </tr>
                                        </thead>
                                        <tbody class="esms_tbody">
                                        <?php
                                        $esms_sanpham = $vhtsms_settings['mess_content_list'];
                                        if($esms_sanpham):
                                            $stt = 0;
                                            foreach ($esms_sanpham as $mess):
                                                $content = isset($mess['content']) ? esc_textarea($mess['content']) : '';
                                                $formID = isset($mess['formID']) ? $mess['formID'] : '';
                                                $sdtField = isset($mess['field_sdt_id']) ? $mess['field_sdt_id'] : '';
                                                $send_admin = isset($mess['send_admin']) ? $mess['send_admin'] : '';
                                                $content_send_admin = isset($mess['content_send_admin']) ? esc_textarea($mess['content_send_admin']) : '';
                                            ?>
                                            <tr>
                                                <td>
                                                    <textarea name="<?php echo $this->_optionName ?>[mess_content_list][id_<?php echo $stt;?>][content]"><?php echo esc_textarea($content);?></textarea>
                                                    <p>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[mess_content_list][id_<?php echo $stt;?>][send_admin]" value="1" <?php checked(1,$send_admin)?>> Gửi tin nhắn cho admin</label>
                                                    </p>
                                                    <p>
                                                        <textarea name="<?php echo $this->_optionName ?>[mess_content_list][id_<?php echo $stt;?>][content_send_admin]" placeholder="Nội dung tin nhắn cho admin"><?php echo esc_textarea($content_send_admin);?></textarea>
                                                    </p>
                                                </td>
                                                <td>
                                                    <select name="<?php echo $this->_optionName ?>[mess_content_list][id_<?php echo $stt;?>][formID]">
                                                        <option value=""><?php _e('Chọn Form','vhtsms');?></option>
                                                        <?php
                                                        if($ninjsSelect){
                                                            echo '<optgroup label="NinjaForms">';
                                                            foreach ($ninjsSelect as $k=>$v){
                                                                echo '<option value="'.$k.'" '.selected($k,$formID,false).'>'.$v.'</option>';
                                                            }
                                                            echo '</optgroup>';
                                                        }
                                                        if($cf7Select){
                                                            echo '<optgroup label="Contact Form 7">';
                                                            foreach ($cf7Select as $k=>$v){
                                                                echo '<option value="'.$k.'" '.selected($k,$formID,false).'>'.$v.'</option>';
                                                            }
                                                            echo '</optgroup>';
                                                        }
                                                        ?>
                                                    </select>
                                                </td>
                                                <td><input type="number" name="<?php echo $this->_optionName ?>[mess_content_list][id_<?php echo $stt;?>][field_sdt_id]" value="<?php echo esc_attr($sdtField);?>"/></td>
                                                <td><input type="button" class="button devvn_button devvn_delete_esms" value="Xóa"></td>
                                            </tr>
                                            <?php $stt++; endforeach;?>
                                        <?php endif;?>
                                        </tbody>
                                        <tfoot>
                                        <tr>
                                            <td colspan="3"><input type="button" class="button devvn_button devvn_add_esms" value="Thêm tin nhắn"></td>
                                        </tr>
                                        </tfoot>
                                    </table>
                                    <small>
                                        <span style="color: red;">Contact Form 7 và NinjaForms:</span> Field số điện thoại <span style="color: red;">BẮT BUỘC</span> phải có tên là <span style="color: red;">your-phone</span><br>
                                        Chú ý: Khi sử dụng Contact Form 7 và NinjaForms 3.x.x thì lấy dữ liệu field bằng cách %%{tên_field}%%<br>
                                        Ví dụ trong form có trường nhập tên là your-name thì trong tin nhắn muốn hiển thị tên sẽ là %%your-name%%<br>
                                        Tương tự lấy trường email khi name="your-email"  thì viết là %%your-email%%<br>
                                        Với NinjaForms bản cũ (2.9.x) thì bắt buộc phải điền ID của field số điện thoại và lấy trường dữ liệu bằng ID dạng %%{ID_FIELD}%%<br>
                                        Ví dụ trường tên có id là 5 thì lấy trong tin nhắn là %%5%%
                                    </small>
                                </td>
                            </tr>
                            </tbody>
                        </table>
                        <script type="text/html" id="tmpl-devvn-tresms">
                            <tr>
                                <td>
                                    <textarea name="<?php echo $this->_optionName ?>[mess_content_list][id_{{data.stt}}][content]"></textarea>
                                    <p>
                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[mess_content_list][id_{{data.stt}}][send_admin]" value="1"> Gửi tin nhắn cho admin</label>
                                    </p>
                                    <p>
                                        <textarea name="<?php echo $this->_optionName ?>[mess_content_list][id_{{data.stt}}][content_send_admin]" placeholder="Nội dung tin nhắn cho admin"></textarea>
                                    </p>
                                </td>
                                <td><select name="<?php echo $this->_optionName ?>[mess_content_list][id_{{data.stt}}][formID]">
                                        <option value=""><?php _e('Chọn Form','vhtsms');?></option>
                                        <?php
                                        if($ninjsSelect){
                                            echo '<optgroup label="NinjaForms">';
                                            foreach ($ninjsSelect as $k=>$v){
                                                echo '<option value="'.$k.'">'.$v.'</option>';
                                            }
                                            echo '</optgroup>';
                                        }
                                        if($cf7Select){
                                            echo '<optgroup label="Contact Form 7">';
                                            foreach ($cf7Select as $k=>$v){
                                                echo '<option value="'.$k.'">'.$v.'</option>';
                                            }
                                            echo '</optgroup>';
                                        }
                                        ?>
                                    </select>
                                </td>
                                <td><input value="" name="<?php echo $this->_optionName ?>[mess_content_list][id_{{data.stt}}][field_sdt_id]" type="number"/></td>
                                <td><input type="button" class="button devvn_button devvn_delete_esms" value="<?php _e('Xóa','vhtsms');?>"></td>
                            </tr>
                        </script>
                        <?php };?>
                        <?php
                        if (
                            in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )
                        ){
                        ?>
                        <h2><?php _e('Cài đặt tin nhắn cho Woocommerce','vhtsms');?></h2>
                        <table class="form-table">
                            <tbody>
                                <tr>
                                    <th scope="row"><label for="enable_woo"><?php _e('Kích hoạt SMS cho Woocommerce', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="checkbox" name="<?php echo $this->_optionName ?>[enable_woo]" id="enable_woo" value="1" <?php checked('1',intval($vhtsms_settings['enable_woo']), true) ; ?>/> Kích hoạt gửi tin nhắn cho Woocommerce
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e('Nội dung tin nhắn', 'vhtsms') ?></th>
                                    <td>
                                        <table class="woo_setting_mess">
                                            <tbody>
                                                <tr>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[account_creat]" id="account_creat" value="1" <?php checked('1',intval($vhtsms_settings['account_creat']), true) ; ?>/> Gửi tin nhắn sau khi tạo tài khoản mới</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[account_creat_mess]"><?php echo esc_textarea($vhtsms_settings['account_creat_mess'])?></textarea>
                                                        <small>Hiển thị TÊN bằng <span style="color: red;">%%name%%</span><br>
                                                            Khi checkout - bắt buộc phải có số điện thoại - billing_phone</small>
                                                    </td>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[order_creat]" id="order_creat" value="1" <?php checked('1',intval($vhtsms_settings['order_creat']), true) ; ?>/> Gửi tin nhắn khi có đơn hàng mới</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[order_creat_mess]"><?php echo esc_textarea($vhtsms_settings['order_creat_mess'])?></textarea>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[woo_status_complete]" id="woo_status_complete" value="1" <?php checked('1',intval($vhtsms_settings['woo_status_complete']), true) ; ?>/> Gửi tin nhắn khi đơn hàng đã hoàn thành (Complete)</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[woo_status_complete_mess]"><?php echo esc_textarea($vhtsms_settings['woo_status_complete_mess'])?></textarea>
                                                    </td>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[woo_status_processing]" id="woo_status_processing" value="1" <?php checked('1',intval($vhtsms_settings['woo_status_processing']), true) ; ?>/> Gửi tin nhắn khi đơn hàng ở trạng thái đang xử lý (Processing)</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[woo_status_processing_mess]"><?php echo esc_textarea($vhtsms_settings['woo_status_processing_mess'])?></textarea>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[woo_status_cancelled]" id="woo_status_cancelled" value="1" <?php checked('1',intval($vhtsms_settings['woo_status_cancelled']), true) ; ?>/> Gửi tin nhắn khi HỦY đơn hàng (Cancelled)</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[woo_status_cancelled_mess]"><?php echo esc_textarea($vhtsms_settings['woo_status_cancelled_mess'])?></textarea>
                                                    </td>
                                                    <td>
                                                        <label><input type="checkbox" name="<?php echo $this->_optionName ?>[order_creat_admin]" id="order_creat_admin" value="1" <?php checked('1',intval($vhtsms_settings['order_creat_admin']), true) ; ?>/> Gửi tin nhắn cho admin khi có đơn hàng mới</label><br>
                                                        <textarea placeholder="Nội dung tin nhắn" name="<?php echo $this->_optionName ?>[order_creat_admin_mess]"><?php echo esc_textarea($vhtsms_settings['order_creat_admin_mess'])?></textarea>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <div class="desc_woo_devvn">
                                            Hiển thị MÃ ĐƠN HÀNG bằng <span style="color: red;">%%orderid%%</span><br>
                                            Hiển thị firstName bằng <span style="color: red;">%%firstName%%</span><br>
                                            Hiển thị lastName bằng <span style="color: red;">%%lastName%%</span><br>
                                            Hiển thị tổng tiền bằng <span style="color: red;">%%total%%</span><br>
                                            Hiển thị số điện thoại khách hàng bằng <span style="color: red;">%%phone%%</span>
                                        </div>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <?php }?>
                        <div class="setting_typesms">
                            <h2>Cài đặt API</h2>
                            <label style="display: none">
                                <input name="<?php echo $this->_optionName ?>[type_api]" type="radio" value="user_pass" <?php checked('user_pass',$vhtsms_settings['type_api']);?>> Gửi bằng User và Pass
                            </label>
                            <label style="display: none">
                                <input name="<?php echo $this->_optionName ?>[type_api]" type="radio" value="api_key" <?php checked('api_key',$vhtsms_settings['type_api']);?>> Gửi bằng API Key
                            </label>
                        </div>
                        <div class="type_api_table <?php echo ($vhtsms_settings['type_api'] == 'user_pass')?'active':'';?>" id="type_api_user_pass">
                            <table class="form-table">
                                <tbody>
                                <tr>
                                    <th scope="row"><label for="user_vht"><?php _e('Account Name', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[user_vht]" id="user_vht" value="<?php echo esc_attr($vhtsms_settings['user_vht']);?>"/>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label for="pass_vht"><?php _e('Account Pass', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[pass_vht]" id="user_pass" value="<?php echo esc_attr($vhtsms_settings['pass_vht']);?>"/>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label for="brandname"><?php _e('Brandname', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[brandname]" id="brandname" value="<?php echo esc_attr($vhtsms_settings['brandname']);?>"/><br>
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                        </div>
                        <div class="type_api_table <?php echo ($vhtsms_settings['type_api'] == 'api_key')?'active':'';?>" id="type_api_api_key">
                            <table class="form-table">
                                <tbody>
                                <tr>
                                    <th scope="row"><label for="apikey"><?php _e('ApiKey', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[apikey]" id="apikey" value="<?php echo esc_attr($vhtsms_settings['apikey']);?>"/>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label for="secretkey"><?php _e('SecretKey', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[secretkey]" id="secretkey" value="<?php echo esc_attr($vhtsms_settings['secretkey']);?>"/>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label for="brandname_api"><?php _e('Brandname', 'vhtsms') ?></label>
                                    </th>
                                    <td>
                                        <input type="text" name="<?php echo $this->_optionName ?>[brandname_api]" id="brandname_api" value="<?php echo esc_attr($vhtsms_settings['brandname_api']);?>"/><br>
                                        <small>Nếu ko có brandname mặc định gửi bằng AlphaSMS (0901800086)</small>
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                        </div>
                        <?php do_settings_fields('vhtsms-options-group', 'default'); ?>
                        <?php do_settings_sections('vhtsms-options-group', 'default'); ?>
                        <?php submit_button(); ?>
                    </form>
                </div>
                <?php
            }
            function sms_cf7_str_replace($sms_mess =  '', $cf7_data = array()){
                if(!$sms_mess || !is_array($cf7_data) || empty($cf7_data)) return $sms_mess;
                preg_match_all ( '/%%(\S*)%%/' , $sms_mess , $matches );
                foreach($matches[1] as $m){
                    $pattern = "/%%".$m."%%/";
                    $this_value = (isset($cf7_data[$m]) && $cf7_data[$m]) ? esc_attr(htmlspecialchars($cf7_data[$m])) : '';
                    $sms_mess = preg_replace( $pattern, $this_value, $sms_mess);
                }
                return $sms_mess;
            }
            function process_contact_form_data( $cf7 ){
                global $vhtsms_settings;
                $list_mess = $vhtsms_settings['mess_content_list'];
                $admin_phone = $vhtsms_settings['admin_phone'];
                $mess_sent = $mess_sent_admin = false;
                if ($vhtsms_settings['kichhoat'] && $list_mess && !empty($list_mess) && !isset($cf7->posted_data) && class_exists('WPCF7_Submission')) {
                    $submission = WPCF7_Submission::get_instance();
                    if ($submission) {
                        $post_data = $submission->get_posted_data();

                        $phone = (isset($post_data['your-phone']) && $post_data['your-phone']) ? esc_attr(htmlspecialchars($post_data['your-phone'])) : '';

                        $_wpcf7ID = intval($post_data['_wpcf7']);
                        $_wpcf7ID = 'cf7_'.$_wpcf7ID;
                        foreach ($list_mess as $mess) {
                            $content = isset($mess['content']) ? esc_textarea($mess['content']) : '';
                            $content = $this->sms_cf7_str_replace($content, $post_data);
                            $formID = isset($mess['formID']) ? $mess['formID'] : '';
                            $send_admin = isset($mess['send_admin']) ? $mess['send_admin'] : '';
                            $content_send_admin = isset($mess['content_send_admin']) ? esc_textarea($mess['content_send_admin']) : '';
                            $content_send_admin = $this->sms_cf7_str_replace($content_send_admin, $post_data);
                            if ($_wpcf7ID == $formID) {
                                if($phone && $content && !$mess_sent) {
                                    $this->send_esms($phone, $content);
                                    $mess_sent = true;
                                }
                                if($admin_phone && $content_send_admin && $send_admin && !$mess_sent_admin){
                                    $this->send_esms($admin_phone, $content_send_admin);
                                    $mess_sent_admin = true;
                                }
                            }
                        }
                    }
                }
                return true;
            }
            function sms_ninja_str_replace($sms_mess = '', $ninja_data = array()){
                if(!$sms_mess || !is_array($ninja_data) || empty($ninja_data)) return $sms_mess;
                preg_match_all ( '/%%(\S*)%%/' , $sms_mess , $matches );
                foreach($matches[1] as $m){
                    $pattern = "/%%".$m."%%/";
                    $this_val = (isset($ninja_data[$m])) ? esc_attr(htmlspecialchars($ninja_data[$m])) : '';
                    $sms_mess = preg_replace( $pattern, $this_val, $sms_mess);
                }
                return $sms_mess;
            }
            function process_ninjaform_data( $form_data ){
                global $vhtsms_settings;
                $list_mess = $vhtsms_settings['mess_content_list'];
                $admin_phone = $vhtsms_settings['admin_phone'];
                if($vhtsms_settings['kichhoat'] && $list_mess && !empty($list_mess)) {
                    $form_fields = $form_data['fields'];
                    $form_id = 'ninja_'.$form_data['form_id'];
                    $mess_sent = $mess_sent_admin = false;
                    foreach ($list_mess as $mess) {
                        $content = isset($mess['content']) ? esc_textarea($mess['content']) : '';
                        $formID = isset($mess['formID']) ? $mess['formID'] : '';
                        $send_admin = isset($mess['send_admin']) ? $mess['send_admin'] : '';
                        $content_send_admin = isset($mess['content_send_admin']) ? esc_textarea($mess['content_send_admin']) : '';
                        $your_phone = $your_name = $your_email = '';
                        $str_replace = array();
                        foreach ($form_fields as $field) {
                            $field_key = $field['key'];
                            $field_value = $field['value'];
                            if($field_key == 'your-phone') $your_phone = $field_value;
                            $str_replace[$field_key] = $field_value;
                        }
                        if ($your_phone && $content && $form_id ==  $formID && !$mess_sent) {
                            $content = $this->sms_ninja_str_replace($content, $str_replace);
                            $this->send_esms($your_phone, $content);
                            $mess_sent = true;
                        }
                        if ($admin_phone && $content_send_admin && $form_id ==  $formID && $send_admin && !$mess_sent_admin) {
                            $content_send_admin = $this->sms_ninja_str_replace($content_send_admin, $str_replace);
                            $this->send_esms($admin_phone, $content_send_admin);
                            $mess_sent_admin = true;
                        }
                    }
                }
            }
            function sms_ninja_old_str_replace($sms_mess = '', $ninja_data = array()){
                if(!$sms_mess || !is_array($ninja_data) || empty($ninja_data)) return $sms_mess;
                preg_match_all ( '/%%(\d*)%%/' , $sms_mess , $matches );
                foreach($matches[1] as $m){
                    $pattern = "/%%".$m."%%/";
                    $this_val = (isset($ninja_data[$m])) ? esc_attr(htmlspecialchars($ninja_data[$m])) : '';
                    $sms_mess = preg_replace( $pattern, $this_val, $sms_mess);
                }
                return $sms_mess;
            }
            function process_ninjaform_data_oldversion(){
                global $vhtsms_settings, $ninja_forms_processing;
                $list_mess = $vhtsms_settings['mess_content_list'];
                $admin_phone = $vhtsms_settings['admin_phone'];
                $form_id = $ninja_forms_processing->get_form_ID();
                if($vhtsms_settings['kichhoat'] && $list_mess && !empty($list_mess)) {
                    $field_data = $ninja_forms_processing->get_all_fields();
                    $form_id = 'ninja_'.$form_id;
                    $mess_sent = $mess_sent_admin = false;
                    foreach ($list_mess as $mess){
                        $content = isset($mess['content']) ? esc_textarea($mess['content']) : '';
                        $formID = isset($mess['formID']) ? $mess['formID'] : '';
                        $field_sdt_id = isset($mess['field_sdt_id']) ? $mess['field_sdt_id'] : '';
                        $send_admin = isset($mess['send_admin']) ? $mess['send_admin'] : '';
                        $content_send_admin = isset($mess['content_send_admin']) ? esc_textarea($mess['content_send_admin']) : '';

                        $your_phone = '';
                        $str_replace = array();
                        foreach ( $field_data as $field_id => $user_value ) {
                            if($field_sdt_id == $field_id){
                                $your_phone = $user_value;
                            }
                            $str_replace[$field_id] = $user_value;
                        }

                        if ($your_phone && $content && $form_id ==  $formID && !$mess_sent) {
                            $content = $this->sms_ninja_old_str_replace($content,$str_replace);
                            $this->send_esms($your_phone, $content);
                            $mess_sent = true;
                        }
                        if ($admin_phone && $content_send_admin && $form_id ==  $formID && $send_admin && !$mess_sent_admin) {
                            $content_send_admin = $this->sms_ninja_old_str_replace($content_send_admin,$str_replace);
                            $this->send_esms($admin_phone, $content_send_admin);
                            $mess_sent_admin = true;
                        }
                    }
                }
            }
            /*Start woo*/
            function sms_woocommerce_created_customer($customer_id, $new_customer_data){
                global $vhtsms_settings;
                $account_creat = $vhtsms_settings['account_creat'];
                $account_creat_mess = $vhtsms_settings['account_creat_mess'];
                $billing_phone = get_user_meta( $customer_id, 'billing_phone', true );
                if ( isset( $_POST['billing_phone'] ) && !$billing_phone) {
                    $billing_phone = sanitize_text_field( $_POST['billing_phone'] );
                }
                if($account_creat && $account_creat_mess && $billing_phone) {
                    $account_creat_mess = str_replace('%%name%%', $new_customer_data['user_login'], $account_creat_mess);
                    $this->send_esms($billing_phone, $account_creat_mess);
                }
            }
            function sms_woo_string_replace($sms_mess = '', $order = '', $order_id = ''){
                if(!$sms_mess || !$order) return $sms_mess;

                if(!$order_id) $order_id = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->id : $order->get_id();

                $billing_first_name = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_first_name : $order->get_billing_first_name();
                if(!$billing_first_name) $billing_first_name = isset($_POST['billing_first_name']) ? sanitize_text_field($_POST['billing_first_name']) : '';

                $billing_last_name = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_last_name : $order->get_billing_last_name();
                if(!$billing_last_name) $billing_last_name = isset($_POST['billing_last_name']) ? sanitize_text_field($_POST['billing_last_name']) : '';

                $billing_phone = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_phone : $order->get_billing_phone();
                if(!$billing_phone) $billing_phone = isset($_POST['billing_phone']) ? sanitize_text_field($_POST['billing_phone']) : '';

                $total =  $order->get_total();
                if(!$total && version_compare( WC_VERSION, '2.7', '<' )) $total = WC()->cart->total;

                $str_replace['firstName'] = $billing_first_name;
                $str_replace['lastName'] = $billing_last_name;
                $str_replace['total'] = $total;
                $str_replace['phone'] = $billing_phone;
                $str_replace['orderid'] = $order_id;

                preg_match_all ( '/%%(\w*)\%%/' , $sms_mess , $matches );
                foreach($matches[1] as $m){
                    $pattern = "/%%".$m."%%/";
                    $sms_mess = preg_replace( $pattern, $str_replace[$m], $sms_mess);
                }
                return $sms_mess;


            }
            function sms_woocommerce_new_order($orderID){
                global $vhtsms_settings;
                $order_creat = $vhtsms_settings['order_creat'];
                $order_creat_mess = $vhtsms_settings['order_creat_mess'];
                $order_creat_admin = $vhtsms_settings['order_creat_admin'];
                $order_creat_admin_mess = $vhtsms_settings['order_creat_admin_mess'];
                $admin_phone = $vhtsms_settings['admin_phone'];

                $order = wc_get_order( $orderID );

                $billing_phone = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_phone : $order->get_billing_phone();
                if(!$billing_phone) $billing_phone = isset($_POST['billing_phone']) ? sanitize_text_field($_POST['billing_phone']) : '';

                if($billing_phone && $order_creat && $order_creat_mess) {
                    $order_creat_mess = $this->sms_woo_string_replace($order_creat_mess, $order);
                    $this->send_esms($billing_phone, $order_creat_mess);
                }
                if($admin_phone && $order_creat_admin && $order_creat_admin_mess){
                    $order_creat_mess = $this->sms_woo_string_replace($order_creat_admin_mess, $order);
                    $this->send_esms($admin_phone, $order_creat_mess);
                }
            }
            function sms_woocommerce_order_status_changed($order_id, $tatus_from, $status_to){
                global $vhtsms_settings;
                $order = wc_get_order( $order_id );
                $billing_phone = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_phone : $order->get_billing_phone();
                if($billing_phone):
                    switch($status_to):
                        case 'completed':
                            if($vhtsms_settings['woo_status_complete'] && $vhtsms_settings['woo_status_complete_mess']){
                                $order_creat_mess = $this->sms_woo_string_replace($vhtsms_settings['woo_status_complete_mess'], $order);
                                $this->send_esms($billing_phone, $order_creat_mess);
                            }
                            break;
                        case 'processing':
                            if($vhtsms_settings['woo_status_processing'] && $vhtsms_settings['woo_status_processing_mess']){
                                $order_creat_mess = $this->sms_woo_string_replace($vhtsms_settings['woo_status_processing_mess'], $order);
                                $this->send_esms($billing_phone, $order_creat_mess);
                            }
                            break;
                        case 'cancelled':
                            if($vhtsms_settings['woo_status_cancelled'] && $vhtsms_settings['woo_status_cancelled_mess']){
                                $order_creat_mess = $this->sms_woo_string_replace($vhtsms_settings['woo_status_cancelled_mess'], $order);
                                $this->send_esms($billing_phone, $order_creat_mess);
                            }
                            break;
                    endswitch;
                endif;
            }
            function devvn_validate_phone_field_process() {
                $billing_phone = filter_input(INPUT_POST, 'billing_phone');
                if ( ! (preg_match('/^0([0-9]{9,10})+$/D', $billing_phone )) ){
                    wc_add_notice( "Xin nhập đúng <strong>số điện thoại</strong> của bạn"  ,'error' );
                }
            }
            /*#Start woo*/
            private function send_esms($YourPhone = '', $Content = ''){
                global $vhtsms_settings;
                if($YourPhone) {
                    $YourPhone = explode(",", $YourPhone);
                    if(is_array($YourPhone) && !empty($YourPhone)) {
                        foreach($YourPhone as $phone){
                            $this->send_vht_single($phone, $Content);
                        }
                    }
                }
            }
            function str_replace_limit($search, $replace, $string, $limit = 1) {
                $pos = strpos($string, $search);
                if ($pos === false || $pos != 0) {
                    return $string;
                }

                $searchLen = strlen($search);

                for ($i = 0; $i < $limit; $i++) {
                    $string = substr_replace($string, $replace, $pos, $searchLen);

                    if ($pos === false || $pos == 0) {
                        break;
                    }
                }

                return $string;
            }
            function vietnam_phone_format($phone = ''){
                if($phone){
                    return $this->str_replace_limit('0', '84', $phone, 1);
                }else{
                    return false;
                }
            }
            private function send_vht_single($YourPhone = '', $Content = '')
            {
                global $vhtsms_settings;
                if($vhtsms_settings['type_api'] == 'user_pass') {
                    $user_vht = $vhtsms_settings['user_vht'];
                    $pass_vht = $vhtsms_settings['pass_vht'];
                    $brandname = $vhtsms_settings['brandname'];

                    if (!$YourPhone || !$Content || !$user_vht || !$pass_vht ) return false;

                    $Content = esc_textarea(remove_accents($Content));
                    if(!$brandname){
                        $brandname = '0901800086';
                    }

                    $YourPhone = $this->vietnam_phone_format($YourPhone);

                    $xmlcontent = '<?xml version="1.0" encoding="utf-8"?>
                                    <soap:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
                                      <soap:Body>
                                        <SendSMS xmlns="http://203.162.168.170/SendMTAuth/">
                                          <account_name>'.$user_vht.'</account_name>
                                          <account_password>'.$pass_vht.'</account_password>
                                          <User_ID>'.$YourPhone.'</User_ID>
                                          <Content>'.$Content.'</Content>
                                          <Service_ID>'.$brandname.'</Service_ID>
                                          <Command_Code>'.$brandname.'</Command_Code>
                                          <Request_ID>0</Request_ID>
                                          <Message_Type>0</Message_Type>
                                          <Total_Message>1</Total_Message>
                                          <Message_Index>1</Message_Index>
                                          <IsMore>0</IsMore>
                                          <Content_Type>0</Content_Type>
                                        </SendSMS>
                                      </soap:Body>
                                    </soap:Envelope>';
                    $URL = "http://sms2.vht.com.vn/SendMTAuth/SendMT2.asmx?wsdl";
                    wp_remote_post($URL, array(
                        'body'    => $xmlcontent,
                        'headers' => array('Content-Type' => 'text/xml'),
                    ));
                }
            }

            public function admin_enqueue_scripts() {
                $current_screen = get_current_screen();
                if ( isset( $current_screen->base ) && $current_screen->base == 'settings_page_setting-vhtsms' ) {
                    wp_enqueue_style('vhtsms-admin-styles', plugins_url('/assets/css/admin-style.css', __FILE__), array(), $this->_version, 'all');
                    wp_enqueue_script('vhtsms-admin-js', plugins_url('/assets/js/admin-jquery.js', __FILE__), array('jquery','wp-util'), $this->_version, true);
                    wp_localize_script('vhtsms-admin-js', 'devvn_esms', array(
                        'ajaxurl'       => admin_url('admin-ajax.php'),
                        'siteurl'       => home_url(),
                    ));
                }
            }
        }

        new VHT_SMS_Class();
    }
}